@@ -34,7 +34,7 @@ class SimplePanel(PanelMixin, SizerMixin, Generic[C]):
         """Init."""
         self._controller = controller
         if scrollable:
-            self._ui_item = ScrolledPanel(parent)
+            self._ui_item= ScrolledPanel(parent)
             self._ui_item.SetupScrolling()
         else:
             self._ui_item = wx.Panel(parent)
@@ -43,7 +43,19 @@ class SimplePanel(PanelMixin, SizerMixin, Generic[C]):
         self._sizer_ = wx.BoxSizer(wx.VERTICAL)
         self.ui_item.SetSizer(self._sizer)
 
+        # useful for image updating layout
+        self._ui_item.Parent.Bind(wx.EVT_SIZE, self._on_size)
+
     @property
     def controller(self) -> C:
         """Return the controller."""
         return self._controller
+
+    def _on_size(self, evt):
+        evt.Skip()
+        self._refresh(evt)
+
+    def _refresh(self,evt):
+
+        _LOGGER.debug("posting size event")
+        self._ui_item.PostSizeEvent()
