@@ -1,7 +1,8 @@
 import logging
 from random import randint
 
-from demo.windows import second_window, third_window
+from demo.windows import second_window, text_wrapping_window, third_window
+from demo.windows.image_view_window import ImageViewWindow
 from events import Events
 
 from aio_wx_widgets.controller import BaseController
@@ -17,6 +18,8 @@ class ControllerOne(BaseController):
         self.int_val: int = 987
         self.a_string_value = None
         self.a_checkbox_value: bool = True
+        self.color_red = None
+        self.ready = False
         super().__init__(model)
 
         self.add_to_log = Events()
@@ -33,6 +36,12 @@ class ControllerOne(BaseController):
     async def open_third_window(self):
         third_window.Window().Show()
 
+    async def open_text_wrapping_window(self):
+        text_wrapping_window.TextWrappingWindow().Show()
+
+    async def open_image_window(self):
+        ImageViewWindow().Show()
+
     async def set_value(self):
         val = randint(1, 100)
         _LOGGER.debug("Setting bound property to %s", val)
