@@ -14,6 +14,8 @@ from aio_wx_widgets.core.validators import float_validator, int_validator
 from aio_wx_widgets.panels.panel import SimplePanel
 from aio_wx_widgets.widgets.button import AioButton
 from aio_wx_widgets.widgets.checkbox import CheckBox
+from aio_wx_widgets.widgets.experimental.fixed_grid import FixedGrid
+from aio_wx_widgets.widgets.image import Image
 from aio_wx_widgets.widgets.labelled_item import LabelledItem
 from aio_wx_widgets.widgets.text import Text
 from aio_wx_widgets.widgets.text_entry import Entry
@@ -46,13 +48,15 @@ class ViewOne(SimplePanel["ControllerOne"]):
         # Use a context manager for container types like a group or grid.
         # A group is a container with a label and a sizer inside. Inside
         # this sizer widgets, or other containers can be placed.
+        # with self.add(DynamicGrid(), weight=1, margin=0) as fixed:
+        #     fixed.add(Text("Col1"),col=0)
+        #     fixed.add(Text("col2"),col=1)
+        #     # fixed.add(Image(IMAGE_FOLDER / "phoenix_main.png"))
 
-        grp = Group("just a group")
-        self.add(grp)
-        grp.add(Text("grp text"))
-        grd = Grid()
-        grp.add(grd)
-        grd.add(Text("grid tedt"))
+        with self.add(FixedGrid(), weight=1, margin=0) as fixed:
+            fixed.add(Text("Col1"))
+            fixed.add(Text("col2"))
+            fixed.add(Image(IMAGE_FOLDER / "phoenix_main.png"))
 
         with self.add(Group("label")) as group:
             group.add(Text(binding=self.bind("int_val"), wrap=True), margin=20)
