@@ -2,6 +2,8 @@ from __future__ import annotations
 
 import logging
 
+from demo.controller.controller_three import ControllerThree
+
 from aio_wx_widgets.containers.grid import Grid
 from aio_wx_widgets.containers.group import Group
 from aio_wx_widgets.core.binding import Binding
@@ -13,9 +15,17 @@ from aio_wx_widgets.widgets.text_entry import Entry
 
 _LOGGER = logging.getLogger(__name__)
 
+_LONG_TEXT = "This is a long text that actually should wrap properly and right from the start. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. This is the last text."
+
 
 class SplitterWindow(TwoSplitterWindow, PanelMixin, SizerMixin):
-    def __init__(self, parent, controller, scrollable=False, window_one_width=250):
+    def __init__(
+        self,
+        parent,
+        controller: ControllerThree,
+        scrollable=False,
+        window_one_width=250,
+    ):
         super().__init__(
             parent, splitter_one_scrollable=False, splitter_two_scrollable=False
         )
@@ -64,34 +74,21 @@ class ViewThree(SplitterWindow):
         with self.add(Grid()) as grd:
             grd.add(AioButton("button one", self._set_value), weight=6)
             grd.add(AioButton("button two,self", self._set_value), weight=6)
-        with self.add(Grid(), margin=20) as grd:
-            grd.add(
-                Text(
-                    "This is a long text that actually should wrap properly and right from the start. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. This is the last text.",
-                    wrap=True,
-                ),
-                weight=1,
-                margin=0,
-            )
 
-        self._btn = AioButton("toggle", self._toggle)
+        self.add(Text(_LONG_TEXT, wrap=True))
+
         with self.add(Grid()) as grd:
             grd.add(AioButton("toggle", self._toggle))
-            grd.add(self._btn)
+            self._btn = grd.add(
+                AioButton("toggle", self._toggle, enabled=self.bind("ready"))
+            )
+            grd.add(Entry(self.bind("bound_text"), enabled=self.bind("ready")))
 
-        # self.add_space(2)
-
-        # self.add(
-        #     self.split_button, hor_align=HorAlign.right,
-        # )
         self._set_split_button_text()
+        # self.ui_item.PostSizeEvent()
 
     def _toggle(self, evt):
-        self._toggle_state = not self._toggle_state
-        if self._toggle_state:
-            self._btn.disable()
-        else:
-            self._btn.enable()
+        self.controller.ready = not self.controller.ready
 
     def _set_split_button_text(self):
         if self.is_split:
