@@ -12,6 +12,8 @@ from aio_wx_widgets import widgets
 logging.basicConfig(level=logging.DEBUG)
 _LOGGER = logging.getLogger(__name__)
 
+IMAGE_PATH = Path(__file__).parent
+
 
 def load_module(module_file: Path):
     """Load and import a module based on the location of the *.py file."""
@@ -48,6 +50,9 @@ def get_all_widget_classes(package):
     for module in get_all_modules(package):
         for _cls in get_all_classes_defined_in_module(module):
             name, cls = _cls
+            if name.startswith("_"):
+                continue
+
             kwargs = {}
             if name == "AioButton":
                 kwargs["label"] = "a label"
@@ -64,13 +69,11 @@ def get_all_widget_classes(package):
             elif name == "LabelledItem":
                 kwargs["label_text"] = "labeltext"
                 kwargs["item"] = Mock()
+            elif name == "Image":
+                kwargs["image"] = Path(IMAGE_PATH / "phoenix_main.png")
             yield name, cls, kwargs
 
 
-# # todo: make this a module based fixture.
-# app = WxAsyncApp()
-
-
 @pytest.mark.parametrize(
     "widget_class,kwargs",
     [
